pub struct SummarizeOlderStrategy { /* private fields */ }Expand description
Strategy that replaces older transcript items with a backend-generated summary.
The most recent keep_last removable items are kept verbatim. Everything
older (excluding items with a preserved ItemKind) is sent to the
configured CompactionBackend for summarisation. The summary items
replace the originals at their position in the transcript.
This strategy requires a backend. If CompactionContext::backend is
None, CompactionError::MissingBackend is returned.
Example
use agentkit_compaction::SummarizeOlderStrategy;
use agentkit_core::ItemKind;
let strategy = SummarizeOlderStrategy::new(8)
.preserve_kind(ItemKind::System);Implementations
Sourceimpl SummarizeOlderStrategy
impl SummarizeOlderStrategy
Sourcepub fn new(keep_last: usize) -> Self
pub fn new(keep_last: usize) -> Self
Create a strategy that keeps the last keep_last removable items and
summarises everything older.
Sourcepub fn preserve_kind(self, kind: ItemKind) -> Self
pub fn preserve_kind(self, kind: ItemKind) -> Self
Mark an ItemKind as preserved so that items of this kind are never
summarised, regardless of their position in the transcript.